@@ -264,9 +264,10 @@ private slots:
         QVERIFY(filterEdit);
         page.show();
         page.activateWindow();
-        QVERIFY(QTest::qWaitForWindowActive(&page));
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
 
         centralView->setFocus();
+        QTest::qWait(50);
         QVERIFY(centralView->hasFocus());
         QVERIFY(!quickAddEdit->hasFocus());
         QVERIFY(!filter->isVisibleTo(&page));
@@ -323,9 +324,10 @@ private slots:
         QVERIFY(filterEdit);
         page.show();
         page.activateWindow();
-        QVERIFY(QTest::qWaitForWindowActive(&page));
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
 
         centralView->setFocus();
+        QTest::qWait(50);
         QVERIFY(centralView->hasFocus());
         QVERIFY(!filter->isVisibleTo(&page));
         QVERIFY(!filterEdit->hasFocus());
@@ -634,7 +636,8 @@ private slots:
         // Needed for shortcuts to work
         page.show();
         page.activateWindow();
-        QVERIFY(QTest::qWaitForWindowActive(&page));
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
+        QTest::qWait(50);
 
         // WHEN
         QTest::keyPress(centralView, Qt::Key_Delete);
@@ -661,7 +664,8 @@ private slots:
         // Needed for shortcuts to work
         page.show();
         page.activateWindow();
-        QVERIFY(QTest::qWaitForWindowActive(&page));
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
+        QTest::qWait(50);
 
         // WHEN
         QTest::keyPress(centralView, Qt::Key_Delete);
@@ -693,7 +697,8 @@ private slots:
         // Needed for shortcuts to work
         page.show();
         page.activateWindow();
-        QVERIFY(QTest::qWaitForWindowActive(&page));
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
+        QTest::qWait(50);
 
         // WHEN
         QTest::keyPress(centralView, Qt::Key_Delete);
@@ -732,7 +737,8 @@ private slots:
         // Needed for shortcuts to work
         page.show();
         page.activateWindow();
-        QVERIFY(QTest::qWaitForWindowActive(&page));
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
+        QTest::qWait(50);
 
         // WHEN
         QTest::keyPress(centralView, Qt::Key_Delete);
@@ -765,7 +771,8 @@ private slots:
         // Needed for shortcuts to work
         page.show();
         page.activateWindow();
-        QVERIFY(QTest::qWaitForWindowActive(&page));
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
+        QTest::qWait(50);
 
         // WHEN
         QTest::keyPress(centralView, Qt::Key_Delete);
